@@ -1,15 +1,15 @@
  /*
  * Project       : ipv6calc
  * File          : db_cc_reg_assignment.h
- * Version       : $Id: 7fc3264017136ac82a11c9a7a5a6473bc6735a0a $
- * Generated     : Mon Jul 12 07:59:02 2021
+ * Version       : $Id: eb2171741f4e2d63a9e2c220325c8aea43e021c3 $
+ * Generated     : Thu Jun  8 18:30:32 2023
  * Data copyright: RIPE NCC, APNIC, ARIN, LACNIC, AFRINIC
  *
  * Information:
  *  Additional header file for databases/lib/libipv6calc_db_wrapper_BuiltIn.c
  */
 
-static const char *db_cc_registry_status = "AFRINIC/20210712 APNIC/20210709 ARIN/20210711 LACNIC/20210708 RIPENCC/20210711";
+static const char *db_cc_registry_status = "AFRINIC/20230608 APNIC/20230608 ARIN/20230608 LACNIC/20230607 RIPENCC/20230607";
 
 static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "", REGISTRY_ARIN     },
@@ -222,7 +222,7 @@ static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "TG", REGISTRY_AFRINIC  },
 	{ "TH", REGISTRY_APNIC    },
 	{ "TJ", REGISTRY_RIPENCC  },
-	{ "TK", REGISTRY_APNIC    },
+	{ "TK", REGISTRY_RIPENCC  },
 	{ "TL", REGISTRY_APNIC    },
 	{ "TM", REGISTRY_RIPENCC  },
 	{ "TN", REGISTRY_AFRINIC  },
@@ -247,7 +247,7 @@ static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "WF", REGISTRY_APNIC    },
 	{ "WS", REGISTRY_APNIC    },
 	{ "YE", REGISTRY_RIPENCC  },
-	{ "YT", REGISTRY_RIPENCC  },
+	{ "YT", REGISTRY_AFRINIC  },
 	{ "ZA", REGISTRY_AFRINIC  },
 	{ "ZM", REGISTRY_AFRINIC  },
 	{ "ZW", REGISTRY_AFRINIC  },
@@ -793,7 +793,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  536  QK
 	{ REGISTRY_UNKNOWN  }, //  537  RK
 	{ REGISTRY_RIPENCC  }, //  538  SK
-	{ REGISTRY_APNIC    }, //  539  TK
+	{ REGISTRY_RIPENCC  }, //  539  TK
 	{ REGISTRY_UNKNOWN  }, //  540  UK
 	{ REGISTRY_UNKNOWN  }, //  541  VK
 	{ REGISTRY_UNKNOWN  }, //  542  WK
@@ -1032,7 +1032,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  775  VT
 	{ REGISTRY_UNKNOWN  }, //  776  WT
 	{ REGISTRY_UNKNOWN  }, //  777  XT
-	{ REGISTRY_RIPENCC  }, //  778  YT
+	{ REGISTRY_AFRINIC  }, //  778  YT
 	{ REGISTRY_UNKNOWN  }, //  779  ZT
 	{ REGISTRY_APNIC    }, //  780  AU
 	{ REGISTRY_UNKNOWN  }, //  781  BU
